gedidb.GediNameMetadata
=======================

.. currentmodule:: gedidb

.. autoclass:: GediNameMetadata

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GediNameMetadata.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GediNameMetadata.product
      ~GediNameMetadata.year
      ~GediNameMetadata.julian_day
      ~GediNameMetadata.hour
      ~GediNameMetadata.minute
      ~GediNameMetadata.second
      ~GediNameMetadata.orbit
      ~GediNameMetadata.sub_orbit_granule
      ~GediNameMetadata.ground_track
      ~GediNameMetadata.positioning
      ~GediNameMetadata.release_number
      ~GediNameMetadata.granule_production_version
      ~GediNameMetadata.major_version_number
   
   